=======
CFDILib 
=======

.. image:: https://badge.fury.io/py/cfdilib.svg
    :target: https://badge.fury.io/py/cfdilib

.. image:: https://travis-ci.org/Vauxoo/cfdilib.svg?branch=master
    :target: https://travis-ci.org/Vauxoo/cfdilib

.. image:: https://codecov.io/gh/Vauxoo/cfdilib/branch/master/graph/badge.svg?token=wcRGfPzSDy
    :target: https://codecov.io/gh/Vauxoo/cfdilib
    
.. image:: https://landscape.io/github/Vauxoo/cfdilib/master/landscape.svg?style=flat
   :target: https://landscape.io/github/Vauxoo/cfdilib/master
   :alt: Code Health

Library to xml documents based on XSD files to manage situations where you need to sign such
documents with a third party, then given a simple dictionary and a jinja2 template you will be
able to generate such documents with almos 0 logic.

* Free software: Vauxoo Licence (LGPL-v3)
* Documentation: https://vauxoo.github.io/cfdilib

Features
--------

* TODO
